#####################################
# installing the package: execute this line just once when first using this script:
install.packages("MCMC.OTU")

#####################################
# Looking for differentially represented OTUs 

library(MCMC.OTU)
library(metagenomeSeq)
vignette("metagenomeSeq")
data(green.data)

dataDirectory <- system.file("extdata", package = "metagenomeSeq") 
lung = load_meta(file.path(dataDirectory, "CHK_NAME.otus.count.csv"))
str(lung$counts)

clin = load_phenoData(file.path(dataDirectory, "CHK_clinical.csv"), tran = TRUE)
ord = match(colnames(lung$counts), rownames(clin)) 

green.count=green.data[,4:156]
green.phen=green.data[,1:2]
green.otu=data.frame(names(green.data)[4:156])
gg=newMRexperiment(t(green.count))
ggn=cumNorm(gg)
str(gg)

nl1=t(MRcounts(ggn, norm = TRUE, log = TRUE))

library(vegan)
library(MCMC.OTU)
data(green.data)
# selecting OTUs present in more that 10% of samples, no restriction on OTU total counts
# (this is more allowing than in teh section above)
goods2=purgeOutliers(green.data,count.columns=4:156,zero.cut=0.1,otu.cut=0)
gcount=goods2[,4:21]
gg=newMRexperiment(t(gcount))
ggn=cumNorm(gg)
nl1=t(MRcounts(ggn, norm = TRUE, log = TRUE))

# creating a log-transfromed normalized dataset for PCA:
nl=logs4pca(data=goods2,count.columns=4:length(names(goods2)))

# PCA:
pcp=prcomp(nl1, retx=TRUE, center=TRUE, scale.=TRUE) 
scores=pcp$x
conditions=goods2[,1:3]
summary(pcp)

# plotting by bank:
margin=0.5
plot(scores[,1], scores[,2],type="n",
	xlim=c(min(scores[,1])-margin,max(scores[,1])+margin),
	ylim=c(min(scores[,2])-margin,max(scores[,2])+margin),
	mgp=c(2.3,1,0),
	xlab=paste("PC1 (",round(summary(pcp)$importance[2,1]*100,1),"%)",sep=""),
	ylab=paste("PC2 (",round(summary(pcp)$importance[2,2]*100,1),"%)",sep=""),
	main="PCA colored by bank")
points(scores[conditions$bank=="east",1],scores[conditions$bank=="east",2])
points(scores[conditions$bank=="west",1],scores[conditions$bank=="west",2],pch=19)
legend("bottomright", c("East","West"), pch=c(1, 19), cex=0.8)

# plotting by species:
margin=0.5
conditions=goods[,1:3]
plot(scores[,1], scores[,2],type="n",
	xlim=c(min(scores[,1])-margin,max(scores[,1])+margin),
	ylim=c(min(scores[,2])-margin,max(scores[,2])+margin),
	mgp=c(2.3,1,0),
	xlab=paste("PC1 (",round(summary(pcp)$importance[2,1]*100,1),"%)",sep=""),
	ylab=paste("PC2 (",round(summary(pcp)$importance[2,2]*100,1),"%)",sep=""),
	main="PCA colored by species")
points(scores[conditions$species=="franksi",1],scores[conditions$species=="franksi",2])
points(scores[conditions$species=="faveolata",1],scores[conditions$species=="faveolata",2],pch=19)
legend("bottomright", c("franksi","faveolata"), pch=c(1, 19), cex=0.8)


#############################################
# exploring correlations between OTUs 

library(MCMC.OTU)
data(green.data)
goods=purgeOutliers(green.data,count.columns=4:156,otu.cut=0.001,zero.cut=0.2)

# creating a log-transformed normalized dataset ignoring zero counts:
nl=logs4pca(data=goods,count.columns=4:length(names(goods)),zero.add=0)
names(nl)=c("I","II","III","IV","V","VI","VII")

# displaying a matrix of scatterplots and p-values of linear regressions
# (onlu p-values better than 0.1 are displayed)
pairs(nl,lower.panel=panel.smooth,upper.panel=panel.cor.pval)

#----------------------------------------
